% Matlab Script steady_state_geotherms_with_heat_production.m
%
% Written by Todd Ehlers, University of Michigan 19 August, 2004
%
% This script generates Figure 1 of Ehlers, T.A. chapter in the MSA volume
% on Low-Temperature Thermochronology
% Equations 4 and 5 in this paper are caculated using the "boot-strapping"
% approach of Chapman, D.S, 1986.

% CLEAR ALL VARIABLES AND CLOSE PLOTS

    clear all
    close all
    
% ****
% **** USER DEFINED PARAMETERS BELOW
% ****
   
    % Boundary Conditions
    To = 0;         % Surface temperature [C]
    qs = [0.040 0.050 0.060 0.070 0.080 0.090];   
                    % Surface heat flow, compare to local measured heat
                    % flow [Wm-2]          
    % Material Properties and Calculation Parameters
    k = 3.0;       % Thermal conductivity at 0 C and 1 atm [units = Wm-1k-1]
    D = 10000;      % Characteristic depth for heat production [m]
    Dlc = 15000;    % Depth to lower crust [m]
    Dman = 35000;   % Depth to upper mantle [m]
    Ao = 0.4*(qs(1)/D);    % Surface heat production [Wm-3], calculated below.
    Alc = 0.45e-6;  % Heat production of the lower crust [uWm-3]
    Aman = 0.02e-6; % Heat production of the upper mantle [uWm-3]
    
    maxz = 35000;   % Maximum depth solution is calculated to [m]
    maxplot = maxz; % Maximum depth to plot solution [m]
    
% **** END USER DEFINED PARAMETERS

% ****
% **** CALCULATE SOLUTION
% ****

    % Define depth range over which solution is calculated 
        z = [0:100:maxz];
        
    % Loop through all depths
    for j=1:length(qs)
        
        % Calculate Ao using empirical heat flow - heat production
        % relationship
        Ao = 0.4*(qs(j)/D);
        
        % Reinitialize Ttop
        Ttop = To;
    for i=1:length(z)-1
        
      % Calculate layer thicknesses between solution points
        dz = z(i+1) - z(i);
        
      % Calculate heat production for interval
        if z(i) < Dlc
            A(i) = Ao*exp(-z(i)/D);
        elseif (z(i) >= Dlc && z(i) < Dman)
            A(i) = Alc;
        else 
            A(i) = Aman;
        end         % end if z(i)
          
      % Calculate temperature and pressure dependent thermal conductivity
      % for interval
      %  if z(i) < Dlc
      %      b=1.5e-3;       % upper crust value [k-1]
      %  else 
      %      b=1.5e-4;       % lower crust value [k-1]
      %  end                 % end if z(i)
      %  c=1.5e-3;           % entire crust average [km-1]
      %  k = ko*(1+c*(z(i)/1000))/(1+b*Ttop);
        
     
      % Calculate Temperature as a function of depth
        if i==1
            Ttop = To;
            qtop = qs(j);
        else
            Ttop = Tbot;
            qtop = qbot;
        end        % end if i     

        T(i,j) = Ttop;                                  % units = C
        Tbot = Ttop + (qtop/k)*dz - (A(i)*dz^2)/(2*k);  % units = C
        qbot = qtop - A(i)*dz;                          % units = Wm-2
        
      % Calculate Thermal Gradient as a Function of Depth
        dT(i,j) = (Tbot - Ttop)/(dz/1000);              % units = C/km
        
        % Calculate heat flow into base of model
        if i==length(z)-1
            qbasal(j)=qbot;
        end
    end             % end for i
    end             % end for j
    
    % Print surface and basal heat flow values to screen
    
    display('Surface Heat Flow (mWm-2) ****************************************')
    qs*1000
    display('Corresponding Basal Heat Flow (mWm-2) ****************************')
    qbasal*1000
    
% ****
% **** PLOT RESULT
% ****
    
    figure
    orient landscape
    
    % Plot Temperatures For Entire Crust
    subplot(121)
        for j=1:length(qs)
        plot(T(:,j),-1*z(1:length(T))/1000)
            if j==1
            hold on
            xlabel('Temperature (C)')
            ylabel('Depth (km)')
            end % end if j
        end     % end for j
        axis([0 800 -1*maxplot/1000 0])
        
    % Plot Temperatures For Uppermost Crust
    subplot(122)
        for j=1:length(qs)
        plot(T(:,j),-1*z(1:length(T))/1000)
            if j==1
            hold on
            xlabel('Temperature (C)')
            %   ylabel('Depth (km)')
            title('Steady-State Geotherms For Variable Surface Heat Flow and Heat Production')
            end % end if j
        end     % end for j
        axis([0 160 -10 0])    
        
    % Plot Thermal Gradients
   % subplot(133)
%        for j=1:length(qs)
%        plot(dT(:,j),-1*z(1:length(T))/1000)
%            if j==1
%            hold on
%            xlabel('Thermal Gradient (C/km)')
%            %   ylabel('Depth (km)')
%            end % end if j
%        end     % end for j
%        axis([5 35 -10 0])    
        
% ****
% **** END OF PROGRAM
% ****